@@ -1,3 +1,6 @@
+from PIL import Image
+import io
+
 
 def multiprocess_pool(process_func: callable,
                       args: list,
@@ -22,3 +25,11 @@ def multiprocess_pool(process_func: callable,
             pool[i].join()
 
 
+def read_bytes(file_name, start_num, size, is_image=True):
+    with open(file_name, 'rb') as f:
+        f.seek(start_num)
+        image = f.read(size)
+    if is_image:
+        image = Image.open(io.BytesIO(image))
+    return image
+
